pub struct GattClientControllerDiscoverServicesResponse {
pub services: Option<Vec<ServiceInfo>>,
/* private fields */
}Fields
services: Option<Vec<ServiceInfo>>Trait Implementations
Sourceimpl Clone for GattClientControllerDiscoverServicesResponse
impl Clone for GattClientControllerDiscoverServicesResponse
Sourcefn clone(&self) -> GattClientControllerDiscoverServicesResponse
fn clone(&self) -> GattClientControllerDiscoverServicesResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<GattClientControllerDiscoverServicesResponse, D> for GattClientControllerDiscoverServicesResponse
impl<D: ResourceDialect> Decode<GattClientControllerDiscoverServicesResponse, D> for GattClientControllerDiscoverServicesResponse
Sourceimpl Default for GattClientControllerDiscoverServicesResponse
impl Default for GattClientControllerDiscoverServicesResponse
Sourcefn default() -> GattClientControllerDiscoverServicesResponse
fn default() -> GattClientControllerDiscoverServicesResponse
Returns the “default value” for a type. Read more
Sourceimpl<D: ResourceDialect> Encode<GattClientControllerDiscoverServicesResponse, D> for &GattClientControllerDiscoverServicesResponse
impl<D: ResourceDialect> Encode<GattClientControllerDiscoverServicesResponse, D> for &GattClientControllerDiscoverServicesResponse
Sourceimpl PartialEq for GattClientControllerDiscoverServicesResponse
impl PartialEq for GattClientControllerDiscoverServicesResponse
Sourcefn eq(&self, other: &GattClientControllerDiscoverServicesResponse) -> bool
fn eq(&self, other: &GattClientControllerDiscoverServicesResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TypeMarker for GattClientControllerDiscoverServicesResponse
impl TypeMarker for GattClientControllerDiscoverServicesResponse
Sourcetype Owned = GattClientControllerDiscoverServicesResponse
type Owned = GattClientControllerDiscoverServicesResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for GattClientControllerDiscoverServicesResponse
impl ValueTypeMarker for GattClientControllerDiscoverServicesResponse
Sourcetype Borrowed<'a> = &'a GattClientControllerDiscoverServicesResponse
type Borrowed<'a> = &'a GattClientControllerDiscoverServicesResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Persistable for GattClientControllerDiscoverServicesResponse
impl StructuralPartialEq for GattClientControllerDiscoverServicesResponse